@@ -206,8 +206,6 @@ struct likelihood_calculator
 
 		MS_DEBUG_STRING_VAR( w_mer, representative( it ) );
 
-		static_cast< Derived * >( this )->entered_node( it, last_length );
-
 		// index into our bounds.
 		typename VertexDescriptor<
 			typename Container< It >::Type
@@ -218,34 +216,40 @@ struct likelihood_calculator
 		// how far down the tree are we?
 		const size_t w = std::min( repLength( it ), likelihoods.W );
 
-		// did we get to the bottom?
-		if( likelihoods.W == w ) {
+		// only deal with nodes that do not have 'N's
+		if( ! _data.contains_n( likelihoods.W, it ) ) {
 
-			// yes, we are at bottom
-			// so calculate the log likelihood
-			double W_mer_min_ll, total_ll;
-			boost::tie( W_mer_min_ll, total_ll ) = static_cast< Derived * >( this )->log_likelihoods_for_w_mer( it );
+	        static_cast< Derived * >( this )->entered_node( it, last_length );
 
-			// update our calculation of part of the LL
-			likelihoods.LL += total_ll;
-			min_ll = std::min( min_ll, W_mer_min_ll );
+            // did we get to the bottom?
+            if( likelihoods.W == w ) {
 
-		} else {
+                // yes, we are at bottom
+                // so calculate the log likelihood
+                double W_mer_min_ll, total_ll;
+                boost::tie( W_mer_min_ll, total_ll ) = static_cast< Derived * >( this )->log_likelihoods_for_w_mer( it );
 
-			// continue : so go down and across
-			if( goDown( it ) ) {
-				min_ll = visit_node( _data, it, w );
-				while( goRight( it ) ) {
-					min_ll = std::min( min_ll, visit_node( _data, it, w ) );
-				}
-			}
-		}
+                // update our calculation of part of the LL
+                likelihoods.LL += total_ll;
+                min_ll = std::min( min_ll, W_mer_min_ll );
 
-		// store the lowest log likelihood
-		MYRRH_ASSERT( min_ll <= 0. ); // perhaps not for empty tree...
-		seqan::assignProperty( likelihoods.min_log, v, min_ll );
+            } else {
 
-        static_cast< Derived * >( this )->left_node( it, last_length );
+                // continue : so go down and across
+                if( goDown( it ) ) {
+                    min_ll = visit_node( _data, it, w );
+                    while( goRight( it ) ) {
+                        min_ll = std::min( min_ll, visit_node( _data, it, w ) );
+                    }
+                }
+            }
+
+            // store the lowest log likelihood
+            MYRRH_ASSERT( min_ll <= 0. ); // perhaps not for empty tree...
+            seqan::assignProperty( likelihoods.min_log, v, min_ll );
+
+            static_cast< Derived * >( this )->left_node( it, last_length );
+        }
 
 		return min_ll;
 	}
@@ -791,7 +795,6 @@ struct markov_wmer_likelihoods_calculator
     log_likelihoods_for_w_mer( It it ) {
         using namespace seqan;
         MS_DEBUG_STRING_VAR( w_mer, representative( it ) );
-        MYRRH_ASSERT( W == current_evals.size() );
         const double it_LL = current_evals.back();
         return boost::make_tuple( it_LL, countOccurrences( it ) * it_LL );
     }
