@@ -807,16 +807,19 @@ def read_sequences(fasta_file, options):
     num_bases, seqs, ids = read_fasta(fasta_file)
     logger.info('Read %d bases from %d sequences in %s', num_bases, len(seqs), fasta_file)
     index = build_index(seqs)
-    if not options.max_num_sites:
-        # allow number of sites up to 3 * # sequences / 2, with hard limit of 10000 if not user-specified
-        hard_limit = 10000
-        options.max_num_sites = min(3 * len(seqs) / 2, hard_limit)
-        if hard_limit == options.max_num_sites:
-            logger.warning('Hit cap of %d on maximum # sites, user can over-ride this with the --max-sites option. High values will slow STEME down.' % hard_limit)
-        logger.info('Set maximum number of sites to %d', options.max_num_sites)
-    if not options.min_num_sites:
-        options.min_num_sites = max(len(seqs) / 10, 2) # always look for at least 2 sites
-        logger.info('Set minimum number of sites to %d', options.min_num_sites)
+    try:
+        if not options.max_num_sites:
+            # allow number of sites up to 3 * # sequences / 2, with hard limit of 10000 if not user-specified
+            hard_limit = 10000
+            options.max_num_sites = min(3 * len(seqs) / 2, hard_limit)
+            if hard_limit == options.max_num_sites:
+                logger.warning('Hit cap of %d on maximum # sites, user can over-ride this with the --max-sites option. High values will slow STEME down.' % hard_limit)
+            logger.info('Set maximum number of sites to %d', options.max_num_sites)
+        if not options.min_num_sites:
+            options.min_num_sites = max(len(seqs) / 10, 2) # always look for at least 2 sites
+            logger.info('Set minimum number of sites to %d', options.min_num_sites)
+    except AttributeError:
+        pass # ignore options that do not have max_num_sites
     return num_bases, seqs, ids, index
 
 
@@ -1886,6 +1889,7 @@ class LogLikelihoodBgModelManager(BgModelManager):
         Return a background model of the sequences for the specified width.
         """
         if W not in self.bg_models:
+            logging.info("Creating background model for W=%d", W)
             self.bg_models[W] = create_bg_model_from_base_likelihoods(
                 W, self.sequences.data, 
                 self.lls, 
